@@ -1,7 +1,7 @@
 use std::hash::{Hash, Hasher};
 
 #[derive(Debug, Copy, Clone)]
-pub(crate) struct PositionCode {
+pub struct PositionCode {
     value: i16
 }
 
@@ -22,19 +22,19 @@ impl Eq for PositionCode {
 
 #[allow(dead_code)]
 impl PositionCode {
-    pub(crate) fn zero() -> PositionCode {
+    pub fn zero() -> PositionCode {
         PositionCode::new()
     }
-    pub(crate) fn new() -> PositionCode {
+    pub fn new() -> PositionCode {
         PositionCode { value: 0 }
     }
-    pub(crate) fn get(_value: i16) -> PositionCode {
+    pub fn get(_value: i16) -> PositionCode {
         PositionCode { value: _value }
     }
-    pub(crate) fn get_value(&self) -> i16 {
+    pub fn get_value(&self) -> i16 {
         self.value
     }
-    pub(crate) fn is_valid(&self) -> bool {
+    pub fn is_valid(&self) -> bool {
         self.value != 0
     }
 }
\ No newline at end of file
